@@ -3,8 +3,6 @@
 #'
 #' @description
 #'
-#'
-#'
 #' Wrapper around `patchwork::wrap_plots` that will return a combined grid of
 #' plots with annotations.
 #'
@@ -22,7 +20,7 @@
 #' @importFrom patchwork wrap_plots plot_annotation
 #' @importFrom rlang exec !!!
 #'
-#' @references
+#' @details For more details, see:
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/combine_plots.html}
 #'
 #' @examples
@@ -30,26 +28,25 @@
 #' library(ggplot2)
 #'
 #' # preparing the first plot
-#' p1 <-
-#'   ggplot2::ggplot(
-#'     data = subset(iris, iris$Species == "setosa"),
-#'     aes(x = Sepal.Length, y = Sepal.Width)
-#'   ) +
+#' p1 <- ggplot2::ggplot(
+#'   data = subset(iris, iris$Species == "setosa"),
+#'   aes(x = Sepal.Length, y = Sepal.Width)
+#' ) +
 #'   geom_point() +
 #'   labs(title = "setosa")
 #'
 #' # preparing the second plot
-#' p2 <-
-#'   ggplot2::ggplot(
-#'     data = subset(iris, iris$Species == "versicolor"),
-#'     aes(x = Sepal.Length, y = Sepal.Width)
-#'   ) +
+#' p2 <- ggplot2::ggplot(
+#'   data = subset(iris, iris$Species == "versicolor"),
+#'   aes(x = Sepal.Length, y = Sepal.Width)
+#' ) +
 #'   geom_point() +
 #'   labs(title = "versicolor")
 #'
 #' # combining the plot with a title and a caption
 #' combine_plots(
 #'   plotlist = list(p1, p2),
+#'   plotgrid.args = list(nrow = 1),
 #'   annotation.args = list(
 #'     tag_levels = "a",
 #'     title = "Dataset: Iris Flower dataset",
@@ -61,15 +58,10 @@
 
 # function body
 combine_plots <- function(plotlist,
-                          guides = "collect",
                           plotgrid.args = list(),
                           annotation.args = list(),
+                          guides = "collect",
                           ...) {
-  rlang::exec(
-    .fn = patchwork::wrap_plots,
-    !!!plotlist,
-    guides = guides,
-    !!!plotgrid.args
-  ) +
-    rlang::exec(.fn = patchwork::plot_annotation, !!!annotation.args)
+  rlang::exec(patchwork::wrap_plots, !!!plotlist, guides = guides, !!!plotgrid.args) +
+    rlang::exec(patchwork::plot_annotation, !!!annotation.args)
 }
