@@ -20,7 +20,6 @@
 #'
 #' @importFrom dplyr select mutate
 #' @importFrom rlang !!! as_name ensym exec
-#' @importFrom paletteer scale_fill_paletteer_d
 #' @importFrom tidyr uncount drop_na
 #' @importFrom statsExpressions contingency_table
 #'
@@ -65,8 +64,7 @@ ggbarstats <- function(data,
                        legend.title = NULL,
                        xlab = NULL,
                        ylab = NULL,
-                       ggtheme = ggplot2::theme_bw(),
-                       ggstatsplot.layer = TRUE,
+                       ggtheme = ggstatsplot::theme_ggstatsplot(),
                        package = "RColorBrewer",
                        palette = "Dark2",
                        ggplot.component = NULL,
@@ -147,25 +145,20 @@ ggbarstats <- function(data,
   # =================================== plot =================================
 
   # dataframe with summary labels
-  df_descriptive <- df_descriptive(data, {{ x }}, {{ y }}, label, perc.k)
+  descriptive_df <- descriptive_df(data, {{ x }}, {{ y }}, label, perc.k)
 
   # dataframe containing all details needed for prop test
-  df_proptest <- df_proptest(data, {{ x }}, {{ y }}, k)
+  onesample_df <- onesample_df(data, {{ x }}, {{ y }}, k)
 
   # if no. of factor levels is greater than the default palette color count
-  palette_message(package, palette, min_length = nlevels(data %>% dplyr::pull({{ x }}))[[1]])
+  palette_message(package, palette, nlevels(data %>% dplyr::pull({{ x }}))[[1]])
 
   # plot
-  p <-
-    ggplot2::ggplot(
-      data = df_descriptive,
-      mapping = ggplot2::aes(x = {{ y }}, y = perc, fill = {{ x }})
-    ) +
+  p <- ggplot2::ggplot(descriptive_df, ggplot2::aes({{ y }}, perc, fill = {{ x }})) +
     ggplot2::geom_bar(
       stat = "identity",
       position = "fill",
-      color = "black",
-      na.rm = TRUE
+      color = "black"
     ) +
     ggplot2::scale_y_continuous(
       labels = function(x) paste0(x * 100, "%"),
@@ -173,13 +166,13 @@ ggbarstats <- function(data,
       minor_breaks = seq(from = 0.05, to = 0.95, by = 0.10)
     ) +
     rlang::exec(
-      .fn = ggplot2::geom_label,
+      ggplot2::geom_label,
       mapping = ggplot2::aes(label = .label, group = {{ x }}),
       show.legend = FALSE,
       position = ggplot2::position_fill(vjust = 0.5),
       !!!label.args
     ) +
-    theme_ggstatsplot(ggtheme, ggstatsplot.layer) +
+    ggtheme +
     ggplot2::theme(panel.grid.major.x = ggplot2::element_blank()) +
     ggplot2::guides(fill = ggplot2::guide_legend(title = legend.title %||% rlang::as_name(x))) +
     paletteer::scale_fill_paletteer_d(paste0(package, "::", palette), name = "")
@@ -191,7 +184,7 @@ ggbarstats <- function(data,
     # modify plot
     p <- p +
       ggplot2::geom_text(
-        data = df_proptest,
+        data = onesample_df,
         mapping = ggplot2::aes(x = {{ y }}, y = 1.05, label = .p.label, fill = NULL),
         size = 2.8,
         parse = TRUE
@@ -201,10 +194,9 @@ ggbarstats <- function(data,
   # adding sample size info
   p <- p +
     ggplot2::geom_text(
-      data = df_proptest,
+      data = onesample_df,
       mapping = ggplot2::aes(x = {{ y }}, y = -0.05, label = N, fill = NULL),
-      size = 4,
-      na.rm = TRUE
+      size = 4
     )
 
   # =========================== putting all together ========================
