@@ -3,8 +3,6 @@
 #'
 #' @description
 #'
-#'
-#'
 #' Scatterplots from `ggplot2` combined with marginal
 #' histograms/boxplots/density plots with statistical details added as a
 #' subtitle.
@@ -56,7 +54,7 @@
 #' @seealso \code{\link{grouped_ggscatterstats}}, \code{\link{ggcorrmat}},
 #' \code{\link{grouped_ggcorrmat}}
 #'
-#' @references
+#' @details For more details, see:
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/ggscatterstats.html}
 #'
 #' @note
@@ -105,7 +103,7 @@ ggscatterstats <- function(data,
                            results.subtitle = TRUE,
                            label.var = NULL,
                            label.expression = NULL,
-                           point.args = list(size = 3, alpha = 0.4),
+                           point.args = list(size = 3, alpha = 0.4, stroke = 0),
                            point.width.jitter = 0,
                            point.height.jitter = 0,
                            point.label.args = list(size = 3, max.overlaps = 1e6),
@@ -120,8 +118,7 @@ ggscatterstats <- function(data,
                            title = NULL,
                            subtitle = NULL,
                            caption = NULL,
-                           ggtheme = ggplot2::theme_bw(),
-                           ggstatsplot.layer = TRUE,
+                           ggtheme = ggstatsplot::theme_ggstatsplot(),
                            ggplot.component = NULL,
                            output = "plot",
                            ...) {
@@ -151,42 +148,42 @@ ggscatterstats <- function(data,
 
   # adding a subtitle with statistical results
   if (isTRUE(results.subtitle)) {
+    # no need to use `tryCatch` because `correlation` already does this
+
     # preparing the BF message for null hypothesis support
     if (type == "parametric" && isTRUE(bf.message)) {
-      caption_df <-
-        statsExpressions::corr_test(
-          data = data,
-          x = {{ x }},
-          y = {{ y }},
-          type = "bayes",
-          bf.prior = bf.prior,
-          top.text = caption,
-          k = k
-        )
+      caption_df <- statsExpressions::corr_test(
+        data = data,
+        x = {{ x }},
+        y = {{ y }},
+        type = "bayes",
+        bf.prior = bf.prior,
+        top.text = caption,
+        k = k
+      )
 
       caption <- caption_df$expression[[1]]
     }
 
     # extracting the subtitle using the switch function
-    subtitle_df <-
-      statsExpressions::corr_test(
-        data = data,
-        x = {{ x }},
-        y = {{ y }},
-        tr = tr,
-        type = type,
-        conf.level = conf.level,
-        k = k
-      )
+    subtitle_df <- statsExpressions::corr_test(
+      data = data,
+      x = {{ x }},
+      y = {{ y }},
+      tr = tr,
+      type = type,
+      conf.level = conf.level,
+      k = k
+    )
 
     subtitle <- subtitle_df$expression[[1]]
   }
 
   # quit early if only subtitle is needed
-  if (output %in% c("subtitle", "caption")) {
+  if (output != "plot") {
     return(switch(output,
-      "subtitle" = subtitle,
-      "caption" = caption
+      "caption" = caption,
+      subtitle
     ))
   }
 
@@ -226,14 +223,8 @@ ggscatterstats <- function(data,
   pos <- ggplot2::position_jitter(width = point.width.jitter, height = point.height.jitter)
 
   # preparing the scatterplot
-  plot <-
-    ggplot2::ggplot(data = data, mapping = ggplot2::aes(x = {{ x }}, y = {{ y }})) +
-    rlang::exec(
-      .fn = ggplot2::geom_point,
-      stroke = 0,
-      position = pos,
-      !!!point.args
-    ) +
+  plot <- ggplot2::ggplot(data, mapping = ggplot2::aes({{ x }}, {{ y }})) +
+    rlang::exec(ggplot2::geom_point, position = pos, !!!point.args) +
     rlang::exec(
       .fn = ggplot2::geom_smooth,
       method = "lm",
@@ -269,22 +260,23 @@ ggscatterstats <- function(data,
       subtitle = subtitle,
       caption = caption
     ) +
-    theme_ggstatsplot(ggtheme, ggstatsplot.layer) +
+    ggtheme +
     ggplot.component
 
   #------------------------- ggMarginal  ---------------------------------
 
-  # creating the `ggMarginal` plot of a given `marginal.type`
+  # adding marginal distributions
   if (isTRUE(marginal)) {
-    if (!requireNamespace("ggExtra")) stop("Package 'ggExtra' needs to be installed.")
-    plot <-
-      ggExtra::ggMarginal(
-        p = plot,
-        type = marginal.type,
-        size = marginal.size,
-        xparams = list(fill = xfill),
-        yparams = list(fill = yfill)
-      )
+    # installed?
+    insight::check_if_installed("ggExtra")
+
+    plot <- ggExtra::ggMarginal(
+      p = plot,
+      type = marginal.type,
+      size = marginal.size,
+      xparams = list(fill = xfill),
+      yparams = list(fill = yfill)
+    )
   }
 
   # return the final plot
