@@ -4,8 +4,6 @@
 #'
 #' @description
 #'
-#'
-#'
 #' Helper function for `ggstatsplot::ggcorrmat` to apply this function across
 #' multiple levels of a given factor and combining the resulting plots using
 #' `ggstatsplot::combine_plots`.
@@ -15,7 +13,7 @@
 #' @inheritDotParams ggcorrmat -title
 #'
 #' @importFrom dplyr select bind_rows
-#' @importFrom rlang !! enquo quo_name ensym %||%
+#' @importFrom rlang !! enquo quo_name ensym
 #' @importFrom purrr map pmap
 #'
 #' @seealso \code{\link{ggcorrmat}}, \code{\link{ggscatterstats}},
@@ -31,12 +29,16 @@
 #' library(ggstatsplot)
 #'
 #' # for plot
-#' grouped_ggcorrmat(
-#'   data = iris,
-#'   grouping.var = Species,
-#'   type = "robust",
-#'   p.adjust.method = "holm"
-#' )
+#' if (require("ggcorrplot")) {
+#'   grouped_ggcorrmat(
+#'     data = iris,
+#'     grouping.var = Species,
+#'     type = "robust",
+#'     p.adjust.method = "holm",
+#'     plotgrid.args = list(ncol = 1),
+#'     annotation.args = list(tag_levels = "i")
+#'   )
+#' }
 #'
 #' # for dataframe
 #' grouped_ggcorrmat(
@@ -64,24 +66,22 @@ grouped_ggcorrmat <- function(data,
 
   # getting the dataframe ready
   if ("cor.vars" %in% names(param_list)) {
-    data %<>% dplyr::select(.data = ., {{ grouping.var }}, {{ cor.vars }})
+    data %<>% dplyr::select({{ grouping.var }}, {{ cor.vars }})
   }
 
   # creating a list for grouped analysis
-  df <-
-    grouped_list(data = data, grouping.var = {{ grouping.var }}) %>%
+  df <- grouped_list(data, grouping.var = {{ grouping.var }}) %>%
     purrr::map(.x = ., .f = ~ dplyr::select(.x, -{{ grouping.var }}))
 
   # ===================== grouped analysis ===================================
 
   # creating a list of results
-  plotlist_purrr <-
-    purrr::pmap(
-      .l = list(data = df, title = names(df)),
-      .f = ggstatsplot::ggcorrmat,
-      output = output,
-      ...
-    )
+  p_ls <- purrr::pmap(
+    .l = list(data = df, title = names(df)),
+    .f = ggstatsplot::ggcorrmat,
+    output = output,
+    ...
+  )
 
   # ===================== combining results ===================================
 
@@ -89,12 +89,12 @@ grouped_ggcorrmat <- function(data,
   # inform user this can't be modified further with ggplot commands
   if (output == "plot") {
     return(combine_plots(
-      plotlist = plotlist_purrr,
+      plotlist = p_ls,
       guides = "keep", # each legend is going to be different
       plotgrid.args = plotgrid.args,
       annotation.args = annotation.args
     ))
   } else {
-    return(dplyr::bind_rows(plotlist_purrr, .id = rlang::as_name(rlang::ensym(grouping.var))))
+    return(dplyr::bind_rows(p_ls, .id = rlang::as_name(rlang::ensym(grouping.var))))
   }
 }
