@@ -21,9 +21,11 @@
 #'
 #' @examples
 #' \donttest{
+#' set.seed(123)
+#' library(ggstatsplot)
+#'
 #' # grouped one-sample proportion test
-#' # let's skip statistical analysis
-#' ggstatsplot::grouped_ggpiestats(
+#' grouped_ggpiestats(
 #'   data = mtcars,
 #'   grouping.var = am,
 #'   x = cyl
@@ -45,29 +47,26 @@ grouped_ggpiestats <- function(data,
   # ======================== preparing dataframe =============================
 
   # creating a dataframe
-  df <-
-    dplyr::select(.data = data, {{ grouping.var }}, {{ x }}, {{ y }}, {{ counts }}) %>%
+  df <- dplyr::select(data, {{ grouping.var }}, {{ x }}, {{ y }}, {{ counts }}) %>%
     grouped_list(grouping.var = {{ grouping.var }})
 
   # ==================== creating a list of return objects ===================
 
   # creating a list of plots using `pmap`
-  plotlist_purrr <-
-    purrr::pmap(
-      .l = list(data = df, title = names(df)),
-      .f = ggstatsplot::ggpiestats,
-      # put common parameters here
-      x = {{ x }},
-      y = {{ y }},
-      counts = {{ counts }},
-      output = output,
-      ...
-    )
+  p_ls <- purrr::pmap(
+    .l = list(data = df, title = names(df)),
+    .f = ggstatsplot::ggpiestats,
+    # put common parameters here
+    x = {{ x }},
+    y = {{ y }},
+    counts = {{ counts }},
+    output = output,
+    ...
+  )
 
   # combining the list of plots into a single plot
-  if (output == "plot") {
-    return(combine_plots(plotlist_purrr, plotgrid.args = plotgrid.args, annotation.args = annotation.args))
-  } else {
-    return(plotlist_purrr) # subtitle list
-  }
+  if (output == "plot") p_ls <- combine_plots(p_ls, plotgrid.args, annotation.args)
+
+  # return the object
+  p_ls
 }
