@@ -8,13 +8,17 @@ test_that(
     # creating the plot
     set.seed(123)
     p <-
-      ggstatsplot::gghistostats(
+      gghistostats(
         data = dplyr::starwars,
         x = height,
         xlab = "character height",
         title = "starwars: character heights",
         binwidth = 20,
-        bar.fill = "orange",
+        bin.args = list(
+          col = "black",
+          fill = "orange",
+          alpha = 0.7
+        ),
         test.value = 150,
         bf.prior = 0.9
       )
@@ -67,7 +71,7 @@ test_that(
     # creating the plot
     set.seed(123)
     p <-
-      ggstatsplot::gghistostats(
+      gghistostats(
         data = ggplot2::mpg,
         x = cty,
         xlab = "city miles per gallon",
@@ -161,7 +165,7 @@ test_that(
     # creating the plot
     set.seed(123)
     p <-
-      ggstatsplot::gghistostats(
+      gghistostats(
         data = mtcars,
         x = wt,
         binwidth = 0.5,
@@ -204,7 +208,7 @@ test_that(
     # plot
     set.seed(123)
     p1 <-
-      ggstatsplot::gghistostats(
+      gghistostats(
         data = ggplot2::msleep,
         x = awake,
         binwidth = 1,
@@ -251,7 +255,7 @@ test_that(
     # should output a list of length 3
     set.seed(123)
     p_sub <-
-      ggstatsplot::gghistostats(
+      gghistostats(
         data = ggplot2::msleep,
         x = brainwt,
         type = "np",
